==> magic-7.2.24.tgz: magic-7.2.24/graphics/grTOGL4.c <==
/* grTOGL4.c -
 *
 *     ********************************************************************* 
 *     * Copyright (C) 1985, 1990 Regents of the University of California. * 
 *     * Permission to use, copy, modify, and distribute this              * 
 *     * software and its documentation for any purpose and without        * 
 *     * fee is hereby granted, provided that the above copyright          * 
 *     * notice appear in all copies.  The University of California        * 
 *     * makes no representations about the suitability of this            * 
 *     * software for any purpose.  It is provided "as is" without         * 
 *     * express or implied warranty.  Export of this software outside     * 
 *     * of the United States of America may require an export license.    * 
 *     *********************************************************************
 *
 * This file contains functions to manage the graphics tablet associated
 * with the X display.
 *
 */

#include <signal.h>
#include <stdio.h>
#include <X11/Xlib.h>

#include "magic/tclmagic.h"
#include "misc/magic.h"
#include "misc/magsgtty.h"
#include "textio/textio.h"
#include "utils/geometry.h"
#include "windows/windows.h"
#include "graphics/graphics.h"
#include "graphics/graphicsInt.h"
#include "textio/txcommands.h"
#include "grTOGLInt.h"

extern Display *grXdpy;


/*---------------------------------------------------------
 * GrTOGLDisableTablet:
 *	Turns off the cursor.
 *
 * Results:	None.
 *
 * Side Effects:    None.		
 *---------------------------------------------------------
 */

Void
GrTOGLDisableTablet ()
{
}


/*---------------------------------------------------------
 * GrTOGLEnableTablet:
 *	This routine enables the graphics tablet.
 *
 * Results: 
 *   	None.
 *
 * Side Effects:
 *	Simply turn on the crosshair.
 *---------------------------------------------------------
 */

Void
GrTOGLEnableTablet ()
{
}


/*
 * ----------------------------------------------------------------------------
 * grtoglGetCursorPos:
 * 	Read the cursor position in magic coordinates.
 *
 * Results:
 *	TRUE is returned if the coordinates were succesfully read, FALSE
 *	otherwise.
 *
 * Side effects:
 *	The parameter is filled in with the cursor position, in the form of
 *	a point in screen coordinates.
 * ----------------------------------------------------------------------------
 */

bool
grtoglGetCursorPos (p)
    Point *p;		/* point to be filled in with screen coordinates */
{
    int x, y, x1, y1, buttons;
    Window win1, win2;
    
    XQueryPointer(grXdpy, XDefaultRootWindow(grXdpy),
		  &win1, &win2, &x1, &y1,
		  &x, &y, &buttons);
    p->p_x = x;
    p->p_y = glTransY(toglCurrent.mw, y);
    return true;
}

==> magic-7.3.37.tgz: magic-7.3.37/graphics/grTOGL4.c <==
/* grTOGL4.c -
 *
 * Copyright 2003 Open Circuit Design, Inc., for MultiGiG Ltd.
 *
 * This file contains functions to manage the graphics tablet associated
 * with the X display.
 *
 */

#include <signal.h>
#include <stdio.h>
#include <X11/Xlib.h>

#include "tcltk/tclmagic.h"
#include "misc/magic.h"
#include "misc/magsgtty.h"
#include "textio/textio.h"
#include "utils/geometry.h"
#include "windows/windows.h"
#include "graphics/graphics.h"
#include "graphics/graphicsInt.h"
#include "textio/txcommands.h"
#include "grTOGLInt.h"

extern Display *grXdpy;


/*---------------------------------------------------------
 * GrTOGLDisableTablet:
 *	Turns off the cursor.
 *
 * Results:	None.
 *
 * Side Effects:    None.		
 *---------------------------------------------------------
 */

void
GrTOGLDisableTablet ()
{
}


/*---------------------------------------------------------
 * GrTOGLEnableTablet:
 *	This routine enables the graphics tablet.
 *
 * Results: 
 *   	None.
 *
 * Side Effects:
 *	Simply turn on the crosshair.
 *---------------------------------------------------------
 */

void
GrTOGLEnableTablet ()
{
}


/*
 * ----------------------------------------------------------------------------
 * grtoglGetCursorPos:
 * 	Read the cursor position in magic coordinates.
 *
 * Results:
 *	TRUE is returned if the coordinates were succesfully read, FALSE
 *	otherwise.
 *
 * Side effects:
 *	The parameter is filled in with the cursor position, in the form of
 *	a point in screen coordinates.
 * ----------------------------------------------------------------------------
 */

bool
grtoglGetCursorPos (mw, p)
    MagWindow *mw;	/* window for which result is given */
    Point *p;		/* point to be filled in with screen coordinates */
{
    int x, y, x1, y1, buttons;
    Window win1, win2;

    if (mw == (MagWindow *)NULL) mw = toglCurrent.mw;
    
    XQueryPointer(grXdpy, Tk_WindowId((Tk_Window)(mw->w_grdata)),
		  &win1, &win2, &x1, &y1,
		  &x, &y, &buttons);
    p->p_x = x;
    p->p_y = glTransY(mw, y);
    return true;
}
